@@ -8,11 +8,11 @@ missing_arg <- function() .Call("missing_arg", PACKAGE = "collections")
 #' The key-value pairs are stored in an R environment.
 #' @section Usage:
 #' \preformatted{
-#' Dict$new()
+#' Dict$new(items = NULL)
 #' Dict$set(key, value)
-#' Dict$get(key, default = NULL)
+#' Dict$get(key, default)
 #' Dict$remove(key)
-#' Dict$pop(key, default = NULL)
+#' Dict$pop(key, default)
 #' Dict$has(key)
 #' Dict$keys()
 #' Dict$values()
@@ -22,18 +22,18 @@ missing_arg <- function() .Call("missing_arg", PACKAGE = "collections")
 #' Dict$as_list()
 #' }
 #' @section Usage:
+#' * `items`: initialization list
 #' * `key`: any R object, key of the item
 #' * `value`: any R object, value of the item
 #' * `default`: optional, the default value of an item if the key is not found
 #' @examples
-#' d <- Dict$new()
-#' d$set("apple", 5)
-#' d$set("orange", 10)
+#' d <- Dict$new(list(apple = 5, orange = 10))
 #' d$set("banana", 3)
 #' d$get("apple")
 #' d$as_list()  # unordered
 #' d$pop("orange")
 #' d$as_list()  # "orange" is removed
+#' d$set("orange", 3)$set("pear", 7)  # chain methods
 #' @seealso [OrderedDict] and [OrderedDictL]
 #' @export
 Dict <- R6::R6Class("Dict",
@@ -42,18 +42,22 @@ Dict <- R6::R6Class("Dict",
         e = NULL
     ),
     public = list(
-        initialize = function() {
+        initialize = function(items = NULL) {
             self$clear()
+            for (argname in names(items)) {
+                self$set(argname, items[[argname]])
+            }
         },
         set = function(key, value) {
             assign(key, value, envir = private$e)
+            invisible(self)
         },
         get = function(key, default = missing_arg()) {
             .Call("dict_get", PACKAGE = "collections", private$e, key, default)
         },
         remove = function(key) {
             .Internal(remove(key, private$e, FALSE))
-            invisible(NULL)
+            invisible(self)
         },
         pop = function(key, default = missing_arg()) {
             v <- self$get(key, default)
@@ -67,7 +71,9 @@ Dict <- R6::R6Class("Dict",
             ls(private$e)
         },
         values = function() {
-            self$as_list()
+            ret <- self$as_list()
+            names(ret) <- NULL
+            ret
         },
         update = function(d) {
             for (key in d$keys()) {
@@ -79,6 +85,10 @@ Dict <- R6::R6Class("Dict",
             private$e <- new.env(hash = TRUE)
         },
         size = function() length(ls(private$e)),
-        as_list = function() as.list(private$e)
+        as_list = function() as.list(private$e),
+        print = function() {
+            n <- self$size()
+            cat("Dict object with", n, "item(s).\n")
+        }
     )
 )
