@@ -1,7 +1,11 @@
-context("OrderedDict")
+for (container in c("OrderedDict", "OrderedDictL")) {
+
+context(container)
+
+Container <- eval(as.name(container))
 
 test_that("push and pop", {
-    d <- OrderedDict$new()
+    d <- Container$new()
     d$set("b", 2)
     d$set("a", 1)
     d$set("c", 3)
@@ -22,7 +26,7 @@ test_that("push and pop", {
 })
 
 test_that("clear", {
-    d <- OrderedDict$new()
+    d <- Container$new()
     d$set("b", 2)
     d$set("a", 1)
     d$set("c", 3)
@@ -31,35 +35,11 @@ test_that("clear", {
 })
 
 
-context("OrderedDictL")
-
-
-test_that("push and pop", {
-    d <- OrderedDictL$new()
-    d$set("b", 2)
-    d$set("a", 1)
-    d$set("c", 3)
-    expect_equal(d$size(), 3)
-    expect_equal(d$get("b"), 2)
-    expect_equal(d$get("a"), 1)
-    expect_equal(d$get("c"), 3)
-    expect_error(d$get("d"), "not found")
-    expect_error(d$pop("d"), "not found")
-    d$remove("b")
-    expect_equal(d$size(), 2)
-    expect_equal(d$pop("a"), 1)
-    expect_equal(d$size(), 1)
-    d$set("c", 5)
-    expect_equal(d$get("c"), 5)
-    expect_equal(d$size(), 1)
-    expect_equal(d$pop("c"), 5)
+test_that("NULL and default", {
+    d <- Container$new()
+    d$set("b", NULL)
+    expect_equal(d$get("b"), NULL)
+    expect_equal(d$get("a", "default"), "default")
 })
 
-test_that("clear", {
-    d <- OrderedDictL$new()
-    d$set("b", 2)
-    d$set("a", 1)
-    d$set("c", 3)
-    d$clear()
-    expect_equal(d$size(), 0)
-})
+}
