@@ -2,9 +2,7 @@ context("PriorityQueue")
 
 test_that("push and pop", {
     q <- PriorityQueue$new()
-    q$push("a", 2)
-    q$push("b", 3)
-    q$push("c", 1)
+    q$push("a", 2)$push("b", 3)$push("c", 1)
     expect_equal(q$size(), 3)
     expect_equal(q$pop(), "b")
     expect_equal(q$size(), 2)
@@ -19,27 +17,19 @@ test_that("push and pop", {
 
 test_that("as_list", {
     q <- PriorityQueue$new()
-    q$push("a", 2)
-    q$push("b", 3)
-    q$push("c", 1)
+    q$push("a", 2)$push("b", 3)$push("c", 1)
     expect_equal(q$as_list(), list("b", "a", "c"))
 })
 
 test_that("as_list", {
     q <- PriorityQueue$new()
-    q$push("a", 2)
-    q$push("b", 3)
-    q$push("d", 2)
-    q$push("c", 1)
+    q$push("a", 2)$push("b", 3)$push("d", 2)$push("c", 1)
     expect_equal(q$as_list(), list("b", "a", "d", "c"))
 })
 
 test_that("clear", {
     q <- PriorityQueue$new()
-    q$push("a", 2)
-    q$push("b", 3)
-    q$push("d", 2)
-    q$push("c", 1)
+    q$push("a", 2)$push("b", 3)$push("d", 2)$push("c", 1)
     q$clear()
     expect_equal(q$size(), 0)
 })
